@@ -16,6 +16,9 @@ DOCUMENTS_PAGE_TREEMENU = getattr(settings, 'DOCUMENTS_PAGE_TREEMENU', "sveedocu
 # Default template to generate flat menu
 DOCUMENTS_PAGE_FLATMENU = getattr(settings, 'DOCUMENTS_PAGE_FLATMENU', "sveedocuments/page_flatmenu.html")
 
+# Enable or disable Pages archiving
+DOCUMENTS_PAGE_ARCHIVED = True
+
 # Available templates for Pages
 DOCUMENTS_PAGE_TEMPLATES = {
     'elastic': ('sveedocuments/page_details/elastic.html', _('Elastic with an unique column')),
@@ -66,13 +69,43 @@ CODEMIRROR_SETTINGS = {
     },
 }
 
+# This is the preface that will be added at start of the Page content when they are 
+# exported to PDF
+# The default preface put some document informations, add summary of content on the 
+# first page and active the section numbering.
+_PDF_PREFACE = u"""==================
+{page.title}
+==================
+
+:author: {page.author.first_name} {page.author.last_name} <{page.author.email}>
+:date: $LastChangedRevision: {page.modified} $
+:revision: $LastChangedRevision: {page.slug} $
+
+.. class:: alert alert-info pull-right
+
+.. contents::
+
+.. section-numbering::
+
+.. raw:: pdf
+
+   PageBreak oneColumn
+
 """
-Internal settings only, can't be modified from your webapp settings
+DOCUMENTS_EXPORT_PDF_PREFACE = getattr(settings, 'DOCUMENTS_EXPORT_PDF_PREFACE', _PDF_PREFACE)
+DOCUMENTS_EXPORT_PDF_HEADER = getattr(settings, 'DOCUMENTS_EXPORT_PDF_PREFACE', "###Section###")
+DOCUMENTS_EXPORT_PDF_FOOTER = getattr(settings, 'DOCUMENTS_EXPORT_PDF_PREFACE', "Page ###Page### / ###Total###")
+
+"""
+Internal settings only, can't be overriden from your webapp settings
 """
 
 # Cache keys for document elements
 PAGE_RENDER_CACHE_KEY_NAME = 'documents-render-page_{id}-setting_{setting}'
+PAGEREV_RENDER_CACHE_KEY_NAME = 'documents-render-page-revision_{id}-setting_{setting}'
 INSERT_RENDER_CACHE_KEY_NAME = 'documents-render-insert_{id}-setting_{setting}-hlv_{header_level}'
 PAGE_TOC_CACHE_KEY_NAME = 'documents-toc-page_{id}-setting_{setting}'
+PAGEREV_TOC_CACHE_KEY_NAME = 'documents-toc-page-revision_{id}-setting_{setting}'
 INSERT_TOC_CACHE_KEY_NAME = 'documents-toc-insert_{id}-setting_{setting}-hlv_{header_level}'
 PAGE_SLUGS_CACHE_KEY_NAME = 'documents-page_slugs'
+PAGE_ATTACHMENTS_SLUGS_CACHE_KEY_NAME = 'documents-page-attachments-slugs'
